# frozen_string_literal: true

require 'treetop'
require_relative './backend_manager.rb'
require_relative './logging.rb'

module DeepAlgo
  module IL
    class Parser
      BASE_PATH = __dir__

      def initialize(curr_backend)
        @curr_backend = curr_backend
        Treetop.load(File.join(BASE_PATH, 'il_parser.treetop'))
        @parser = IlParser.new
      end

      def parse(input)
        data = input.gsub(/(?:#.+?#)/, '')
        tree = nil
        begin
          tree = @parser.parse(data)
        rescue StandardError
          DeepAlgo::IL.log.debug('Error when parsing the file')
          DeepAlgo::IL.log.debug(input.to_s)
        end
        DeepAlgo::IL.log.debug(@parser.failure_reason) if tree.nil?
        tree
      end
    end
  end
end
